# yzm_util

> **`File read and write operations`**

This is a simple log package. You can see
[Github-yzm_util](https://github.com/YuZhengM/yzm_util)
[PyPI-yzm_util](https://pypi.org/project/yzm_util/)

## Use

> install

```shell
pip install yzm_util
```

> import

```shell
import yzm_util as yu
```

